@@ -144,3 +144,9 @@ Arcsine$set("public","initialize",function(lower = 0, upper = 1, decorators = NU
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "Arc", ClassName = "Arcsine",
+                                               Type = "\u211D", ValueSupport = "continuous", VariateForm = "univariate",
+                                               Package = "distr6"))
+
